==> sight_24.1.0.orig.tar.gz: sight-24.1.0/examples/core/ex_timeline/main.cpp <==
/************************************************************************
 *
 * Copyright (C) 2014-2023 IRCAD France
 * Copyright (C) 2014-2020 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "main.hpp"

#include <data/composite.hpp>

#include <service/macros.hpp>

namespace ex_timeline
{

//------------------------------------------------------------------------------

main::main() noexcept =
    default;

//------------------------------------------------------------------------------

main::~main() noexcept =
    default;

//------------------------------------------------------------------------------

void main::starting()
{
}

//------------------------------------------------------------------------------

void main::stopping()
{
}

//------------------------------------------------------------------------------

void main::updating()
{
    // This allows us to block the main thread...
    std::ignore = getchar();
}

//------------------------------------------------------------------------------

void main::configuring()
{
}

//------------------------------------------------------------------------------

} // namespace ex_timeline.

==> sight_25.0.0.orig.tar.gz: sight-25.0.0/examples/core/ex_timeline/main.cpp <==
/************************************************************************
 *
 * Copyright (C) 2014-2024 IRCAD France
 * Copyright (C) 2014-2020 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#include "main.hpp"

#include <data/map.hpp>

#include <service/macros.hpp>

namespace ex_timeline
{

//------------------------------------------------------------------------------

main::main() noexcept =
    default;

//------------------------------------------------------------------------------

main::~main() noexcept =
    default;

//------------------------------------------------------------------------------

void main::starting()
{
}

//------------------------------------------------------------------------------

void main::stopping()
{
}

//------------------------------------------------------------------------------

void main::updating()
{
    // This allows us to block the main thread...
    std::ignore = getchar();
}

//------------------------------------------------------------------------------

void main::configuring()
{
}

//------------------------------------------------------------------------------

} // namespace ex_timeline.
